@@ -1,15 +1,15 @@
 context("emission")
 
-test_that("final emission works", {
+test_that("emission function works", {
 
   g          <- gridInfo(paste0(system.file("extdata", package = "EmissV"),"/wrfinput_d01"))
   g$map_proj <- 2 # using old method
 
-  expect_equal(emission(totalEmission(vehicles(example = TRUE,verbose = F),
+  expect_equal(emission(total = totalEmission(vehicles(example = TRUE,verbose = F),
                                       emissionFactor(example = TRUE,verbose = F),
                                       pol = c("CO"),verbose = T),
-                        "FISH",
-                        list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[22,1],
+                        pol = "FISH",
+                        area = list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[22,1],
                                              raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
                                              g,
                                              name = "SP",verbose = F),
@@ -17,15 +17,15 @@ test_that("final emission works", {
                                              raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
                                              g,
                                              name = "RJ",verbose = F)),
-                        g,
+                        grid = g,
                         verbose = F),
                cat(paste("FISH","not found in total !\n")))
 
-  expect_equal(sum(emission(totalEmission(vehicles(example = TRUE,verbose = F),
+  expect_equal(sum(emission(total = totalEmission(vehicles(example = TRUE,verbose = F),
                                           emissionFactor(example = TRUE,verbose = F),
                                           pol = c("CO"),verbose = T),
-                            "CO",
-                            list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[22,1],
+                            pol = "CO",
+                            area = list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[22,1],
                                                  raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
                                                  g,
                                                  name = "SP",verbose = F),
@@ -33,7 +33,7 @@ test_that("final emission works", {
                                                  raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
                                                  g,
                                                  name = "RJ",verbose = F)),
-                            g,
+                            grid = g,
                             mm=28,
                             verbose = T,
                             aerosol = T,
@@ -43,15 +43,15 @@ test_that("final emission works", {
 
   # g$map_proj <- 1 # using new method
 
-  expect_equal(sum(emission(totalEmission(vehicles(example = TRUE,verbose = F),
+  expect_equal(sum(emission(total = totalEmission(vehicles(example = TRUE,verbose = F),
                                           emissionFactor(example = TRUE,verbose = F),
                                           pol = c("CO"),verbose = F),
-                            "CO",
-                            list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[17,1],
-                                                 raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
-                                                 g,
-                                                 name = "SP",verbose = F)),
-                            g,
+                            pol = "CO",
+                            area = list(SP = areaSource(raster::shapefile(paste0(system.file("extdata", package = "EmissV"),"/BR.shp"))[17,1],
+                                                        raster::raster(paste0(system.file("extdata", package = "EmissV"),"/dmsp.tiff")),
+                                                        g,
+                                                        name = "SP",verbose = F)),
+                            grid = g,
                             mm=28,
                             verbose = T,
                             aerosol = F,
@@ -59,12 +59,10 @@ test_that("final emission works", {
   ) > units::as_units(1, "ug*m^-2*s^-1"),
   TRUE)
 
-  expect_equal(nrow(emission(inventory = read("edgar_co_test.nc",version = "EDGAR"),pol = "FISH",
-                            grid = g,
-                            mm=1,plot = T,verbose = T)
-  ),
-  nrow(emission(inventory = read("edgar_co_test.nc",version = "EDGAR"),pol = "FISH",
-               grid = g,
-               mm=1,plot = T, aerosol = T)
-  ))
+  g   <- gridInfo(paste0(system.file("extdata", package = "EmissV"),"/wrfinput_d01"))
+  ed  <- read("edgar_co_test.nc",version = "EDGAR")
+  a   <- emission(inventory = ed,grid = g,plot = T,verbose = T, pol = 'FISH')
+  b   <- emission(inventory = ed,grid = g,plot = T,verbose = T,aerosol = T)
+
+  expect_equal(nrow(a),nrow(b))
 })
